@@ -331,8 +331,8 @@ sub get_ref_value {
     );
     return Javonet::Sdk::Internal::InvocationContext->new(
         $self->{runtime_name},
-        $self->get_connection_type(),
-        $self->get_tcp_address(),
+        $self->{connection_type},
+        $self->{tcp_address},
         $self->build_command($command),
         0
     );
@@ -347,8 +347,40 @@ sub create_null {
     );
     return Javonet::Sdk::Internal::InvocationContext->new(
         $self->{runtime_name},
-        $self->get_connection_type(),
-        $self->get_tcp_address(),
+        $self->{connection_type},
+        $self->{tcp_address},
+        $self->build_command($command),
+        0
+    );
+}
+
+sub get_static_method_as_delegate {
+    my ($self, @arguments) = @_;
+    my $command = PerlCommand->new(
+        runtime => $self->{runtime_name},
+        command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('GetStaticMethodAsDelegate'),
+        payload => \@arguments
+    );
+    return Javonet::Sdk::Internal::InvocationContext->new(
+        $self->{runtime_name},
+        $self->{connection_type},
+        $self->{tcp_address},
+        $self->build_command($command),
+        0
+    );
+}
+
+sub get_instance_method_as_delegate {
+    my ($self, @arguments) = @_;
+    my $command = PerlCommand->new(
+        runtime => $self->{runtime_name},
+        command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('GetInstanceMethodAsDelegate'),
+        payload => \@arguments
+    );
+    return Javonet::Sdk::Internal::InvocationContext->new(
+        $self->{runtime_name},
+        $self->{connection_type},
+        $self->{tcp_address},
         $self->build_command($command),
         0
     );
@@ -377,15 +409,25 @@ sub build_command {
 sub encapsulate_payload_item {
     my ($self, $payload_item) = @_;
 
-    if(!defined $payload_item) {
+    if (!defined $payload_item) {
         return PerlCommand->new(
-            runtime => $self->{runtime_name},
+            runtime      => $self->{runtime_name},
             command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Value'),
-            payload => []
+            payload      => []
         );
     }
-
-    if ($payload_item->isa('Command')) {
+    if (ref($payload_item) eq 'ARRAY') {
+        my $payload_length = @$payload_item;
+        for (my $i = 0; $i < $payload_length; $i++) {
+            $payload_item->[$i] = $self->encapsulate_payload_item($payload_item->[$i]);
+        }
+        return PerlCommand->new(
+            runtime      => $self->{runtime_name},
+            command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Array'),
+            payload      => $payload_item
+        );
+    }
+    elsif ($payload_item->isa('Command')) {
         my $payload_length = @{$payload_item->{payload}};
         for (my $i = 0; $i < $payload_length; $i++) {
             $payload_item->{payload}[$i] = $self->encapsulate_payload_item($payload_item->{payload}[$i]);
@@ -395,22 +437,11 @@ sub encapsulate_payload_item {
     elsif ($payload_item->isa('Javonet::Sdk::Internal::InvocationContext')) {
         return $payload_item->get_current_command();
     }
-    elsif (ref($payload_item) eq 'ARRAY') {
-        my $payload_length = @$payload_item;
-        for (my $i = 0; $i < $payload_length; $i++) {
-            $payload_item->[$i] = $self->encapsulate_payload_item($payload_item->[$i]);
-        }
-        return PerlCommand->new(
-            runtime => $self->{runtime_name},
-            command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Array'),
-            payload => $payload_item
-        );
-    }
     else {
         return PerlCommand->new(
-            runtime => $self->{runtime_name},
+            runtime      => $self->{runtime_name},
             command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Value'),
-            payload => [$payload_item]
+            payload      => [ $payload_item ]
         );
     }
 }
